summaryrefslogtreecommitdiffstats
path: root/cpukit/posix/include/rtems/posix/threadsup.h
diff options
context:
space:
mode:
authorSebastian Huber <sebastian.huber@embedded-brains.de>2015-12-14 13:10:24 +0100
committerSebastian Huber <sebastian.huber@embedded-brains.de>2015-12-15 07:41:34 +0100
commit173d1f84736c50cdfbd058b2570d698957b7ba94 (patch)
treec92e5aceb83cb3e041039e9a4d47b1bd4c97249a /cpukit/posix/include/rtems/posix/threadsup.h
parentscore: Initialize thread control to zero (diff)
downloadrtems-173d1f84736c50cdfbd058b2570d698957b7ba94.tar.bz2
posix: Store unblocked signals
Store the unblock signals to exploit the zero-initialization of the thread control block.
Diffstat (limited to '')
-rw-r--r--cpukit/posix/include/rtems/posix/threadsup.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/cpukit/posix/include/rtems/posix/threadsup.h b/cpukit/posix/include/rtems/posix/threadsup.h
index ae122962bc..bf80c6314a 100644
--- a/cpukit/posix/include/rtems/posix/threadsup.h
+++ b/cpukit/posix/include/rtems/posix/threadsup.h
@@ -63,8 +63,8 @@ typedef struct {
*/
Watchdog_Control Sporadic_timer;
- /** This is the set of signals which are currently blocked. */
- sigset_t signals_blocked;
+ /** This is the set of signals which are currently unblocked. */
+ sigset_t signals_unblocked;
/** This is the set of signals which are currently pending. */
sigset_t signals_pending;